PanoramaState class

Inheritance
Mixed-in types

Constructors

PanoramaState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
latitudeDelta double
getter/setter pair
latitudeRad double
getter/setter pair
longitudeDelta double
getter/setter pair
longitudeRad double
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
orientation ↔ Vector3
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scene ↔ Scene?
getter/setter pair
screenOrientationRad double
getter/setter pair
surface ↔ Object?
getter/setter pair
textureProvider ↔ PanoramaTextureProvider?
getter/setter pair
widget PanoramaViewer
The current configuration.
no setterinherited
zoomDelta double
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildHotspotWidgets(List<Hotspot>? hotspots) Widget
createTicker(TickerCallback onTick) Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant PanoramaViewer oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
initState() → void
Called when this object is inserted into the tree.
override
matrixFromLatLon(double lat, double lon) Matrix4
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionFromLatLon(double lat, double lon) → Vector3
positionToLatLon(double x, double y) → Vector3
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited