onImageLoad property
dynamic Function()?
onImageLoad
final
This event will be called when provided image is loaded on texture.
Implementation
final Function()? onImageLoad;
This event will be called when provided image is loaded on texture.
final Function()? onImageLoad;