onLongPressStart property

dynamic Function(double longitude, double latitude, double tilt)? onLongPressStart
final

This event will be called when the user has started a long press, it contains latitude and longitude about where the user pressed.

Implementation

final Function(double longitude, double latitude, double tilt)?
    onLongPressStart;